pub fn read_json<T: DeserializeOwned>(path: impl Into<PathBuf>) -> Result<T>Expand description
Reads and deserializes a JSON value from the file at the given path.
pub fn read_json<T: DeserializeOwned>(path: impl Into<PathBuf>) -> Result<T>Reads and deserializes a JSON value from the file at the given path.